@@ -1,4 +1,3 @@
-from contextlib import ContextDecorator
 from typing import ContextManager, Final
 
 from injection import mod
@@ -22,7 +21,5 @@ test_injectable = mod(_TEST_PROFILE_NAME).injectable
 test_singleton = mod(_TEST_PROFILE_NAME).singleton
 
 
-def load_test_profile(
-    *other_profile_names: str,
-) -> ContextManager[None] | ContextDecorator:
-    return load_profile(_TEST_PROFILE_NAME, *other_profile_names)
+def load_test_profile(*names: str) -> ContextManager[None]:
+    return load_profile(_TEST_PROFILE_NAME, *names)
